package com.akamai.ampdemoui;

import android.app.Activity;
import android.os.Bundle;
import android.widget.Toast;

import com.akamai.captioning.CaptionComponent;
import com.akamai.media.VideoPlayerContainer;
import com.akamai.media.VideoPlayerView;
import com.akamai.media.elements.AMPLibraryInfo;
import com.akamai.media.elements.MediaResource;
import com.akamai.media.exowrapper2.SideloadedCaptionsData;
import com.akamai.uimobile.listeners.IMediaPlayerControllerListener;
import com.akamai.uimobile.media.MediaPlayerController;
import com.akamai.utils.LogManager;

import java.util.List;


public class MainActivity extends Activity
        implements IMediaPlayerControllerListener, VideoPlayerContainer.VideoPlayerContainerCallback {

    private static final String LOG_TAG = "AMP-Sideloading-Sample";
    private static final String AMP_LICENSE = "isb3QJbqz9b2sDKO-362MyavEGd2EEH9aOSjSyWFHKB25jLLGy3xgyAYtFD_24uph3p0_1FPucKkslJbheijqQ==";

    private static final String MEDIA_ASSET_URL = "http://multiplatform-f.akamaihd.net/i/multi/will/bunny/big_buck_bunny_,640x360_400,640x360_700,640x360_1000,950x540_1500,.f4v.csmil/master.m3u8";

    private static final String WEBVTTS_A = "http://projects.mediadev.edgesuite.net/customers/akamai/android/doc/vtt-sideload-playlista.m3u8";
    private static final String WEBVTTS_B = "http://projects.mediadev.edgesuite.net/customers/akamai/android/doc/vtt-sideload-playlistb.m3u8";
    private static final String WEBVTTS_C = "http://projects.mediadev.edgesuite.net/customers/akamai/android/doc/vtt-sideload-playlistc.m3u8";
    private static final String WEBVTTS_D = "http://projects.mediadev.edgesuite.net/customers/akamai/android/doc/vtt-sideload-playlistd.m3u8";


    private VideoPlayerContainer videoPlayerContainer;
    private VideoPlayerView videoPlayerView;
    private MediaPlayerController mediaPlayerController;
    private CaptionComponent captionComponent;


    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);
        captionComponent = (CaptionComponent) findViewById(R.id.captionView);
        videoPlayerContainer = (VideoPlayerContainer) findViewById(R.id.playerViewCtrl);
        videoPlayerContainer.addVideoPlayerContainerCallback(this);
        videoPlayerContainer.prepareResource(MEDIA_ASSET_URL);
    }

    @Override
    public void onVideoPlayerCreated() {
        LogManager.log(LOG_TAG, "onVideoPlayerCreated()");
    }

    @Override
    public void onResourceReady(MediaResource mediaResource) {
        videoPlayerView = videoPlayerContainer.getVideoPlayer();
        videoPlayerView.setLicense(AMP_LICENSE);
        videoPlayerView.setLogEnabled(true);

        mediaPlayerController = (MediaPlayerController) findViewById(R.id.playerControls);
        mediaPlayerController.setVideoPlayerView(videoPlayerContainer);
        mediaPlayerController.setEventsListener(MainActivity.this);
        mediaPlayerController.showCCButtonWithCaptionsDisabled();

        captionComponent.setVideoPlayerView(videoPlayerView);
        //Typeface font = Typeface.createFromAsset(getAssets(), "fonts/Calligraffiti.ttf");
        //captionComponent.setTypeface(font);

        captionComponent.preloadExternalCaptions(
                new SideloadedCaptionsData("english",  "en", WEBVTTS_A),
                new SideloadedCaptionsData("french",   "fr", WEBVTTS_B),
                new SideloadedCaptionsData("japanese", "jp", WEBVTTS_C),
                new SideloadedCaptionsData("spanish",  "es", WEBVTTS_D));

        videoPlayerView.play(mediaResource);

        LogManager.log(LOG_TAG, "AMP v" + AMPLibraryInfo.VERSION);
    }

    @Override
    public void onResourceError() {
        LogManager.error(LOG_TAG, "onResourceError()");
    }

    @Override
    public void onButtonClicked(int buttonID) {
        if(buttonID == IMediaPlayerControllerListener.MEDIAPLAYERCONTROLLER_CAPTIONS_ON) {
            captionComponent.enableCaptioning(true);
        }
        else if(buttonID == IMediaPlayerControllerListener.MEDIAPLAYERCONTROLLER_CAPTIONS_OFF)
        {
            captionComponent.enableCaptioning(false);
        } else if(buttonID == IMediaPlayerControllerListener.MEDIAPLAYERCONTROLLER_BUTTON_FULLSCREEN)
        {
            loadNextSubtitles();
        }
    }

    private int currentIndex = -1;

    private void loadNextSubtitles() {
        List<SideloadedCaptionsData> subtitles = captionComponent.getSideloadedCaptions();
        if (subtitles.isEmpty())
            return;

        currentIndex++;
        if (currentIndex >= subtitles.size())
            currentIndex = 0;

        captionComponent.setTrackIndex(currentIndex);
        SideloadedCaptionsData currentSubtitle = subtitles.get(currentIndex);
        Toast.makeText(this, "Loading: " + currentSubtitle.getLanguageName(), Toast.LENGTH_SHORT).show();
    }

}
