package fragment;

import android.app.Activity;
import android.graphics.Color;
import android.os.Bundle;
import android.util.Log;
import android.view.LayoutInflater;
import android.view.MotionEvent;
import android.view.View;
import android.view.ViewGroup;
import android.widget.ProgressBar;
import android.widget.Toast;

import com.akamai.captioning.CaptionComponent;
import com.akamai.captioning.ampcaptioningsample.MainActivity;
import com.akamai.captioning.ampcaptioningsample.R;
import com.akamai.media.IPlayerEventsListener;
import com.akamai.media.VideoPlayerContainer;
import com.akamai.media.VideoPlayerView;
import com.akamai.media.elements.MediaResource;
import com.akamai.media.exowrapper2.SideloadedCaptionsData;

import java.util.List;

public class WebVTTFragment extends android.support.v4.app.Fragment
        implements View.OnTouchListener, IPlayerEventsListener {

    private final static String TAG = "AMP-CC-WEBVTT";
    private final static String VIDEO_URL = "http://multiplatform-f.akamaihd.net/i/multi/will/bunny/big_buck_bunny_,640x360_400,640x360_700,640x360_1000,950x540_1500,.f4v.csmil/master.m3u8";

    private static final String DOT_VTT_CAPTIONS = "http://projects.mediadev.edgesuite.net/customers/akamai/android/doc/sample.vtt";

    private static final String HLS_WITH_VTTS = "http://projects.mediadev.edgesuite.net/customers/akamai/android/doc/vtt-sideload-playlist.m3u8";

    private static final String WEBVTTS_A = "http://projects.mediadev.edgesuite.net/customers/akamai/android/doc/vtt-sideload-playlista.m3u8";
    private static final String WEBVTTS_B = "http://projects.mediadev.edgesuite.net/customers/akamai/android/doc/vtt-sideload-playlistb.m3u8";
    private static final String WEBVTTS_C = "http://projects.mediadev.edgesuite.net/customers/akamai/android/doc/vtt-sideload-playlistc.m3u8";
    private static final String WEBVTTS_D = "http://projects.mediadev.edgesuite.net/customers/akamai/android/doc/vtt-sideload-playlistd.m3u8";



    private VideoPlayerContainer mVideoContainer;
    private VideoPlayerView mVideoPlayerView;
    private ProgressBar mProgressBar;


    private CaptionComponent captionComponent;


    public static WebVTTFragment newInstance() {
        WebVTTFragment fragment = new WebVTTFragment();
        return fragment;
    }

    public WebVTTFragment() {
    }

    @Override
    public View onCreateView(LayoutInflater inflater, ViewGroup container,
                             Bundle savedInstanceState) {

        View rootView = inflater.inflate(R.layout.fragment_main, container, false);
        mProgressBar = (ProgressBar) rootView.findViewById(R.id.progressBar);

        captionComponent = (CaptionComponent) rootView.findViewById(R.id.captionView);

        mVideoContainer = (VideoPlayerContainer) rootView.findViewById(R.id.playerViewCtrl);
        mVideoContainer.addVideoPlayerContainerCallback(new VideoPlayerContainer.VideoPlayerContainerCallback() {
            @Override
            public void onVideoPlayerCreated() {
                Log.i(TAG, "onVideoPlayerCreated()");
            }

            @Override
            public void onResourceReady(MediaResource mediaResource) {
                mVideoPlayerView = mVideoContainer.getVideoPlayer();
                mVideoPlayerView.setProgressBarControl(mProgressBar);
                mVideoPlayerView.setLicense(MainActivity.LICENSE);

                mVideoPlayerView.setFullScreen(true);
                mVideoPlayerView.setFullScreenMode(VideoPlayerView.FULLSCREEN_MODE_KEEP_ASPECT_RATIO);
                mVideoPlayerView.setLogEnabled(true);

                initCaptions();

                mVideoPlayerView.addEventsListener(WebVTTFragment.this);
                mVideoPlayerView.setKeepScreenOn(true);
                mVideoPlayerView.setOnTouchListener(WebVTTFragment.this);

                mVideoPlayerView.play(mediaResource);
            }

            @Override
            public void onResourceError() {
                Log.e(TAG, "onResourceError()");
            }
        });

        mVideoContainer.prepareResource(VIDEO_URL);

        return rootView;
    }

    /**
     * Caption configuration
     */
    private void initCaptions(){
        captionComponent.setVideoPlayerView(mVideoPlayerView);

        captionComponent.loadExternalVTTResource("english",  "en", DOT_VTT_CAPTIONS);

        //captionComponent.loadExternalM3u8Resource(HLS_WITH_VTTS);

        // External VTT file, for media assets with no integrated captions
        /*captionComponent.preloadExternalCaptions(
                new SideloadedCaptionsData("english",  "en", WEBVTTS_A),
                new SideloadedCaptionsData("french",   "fr", WEBVTTS_B),
                new SideloadedCaptionsData("japanese", "jp", WEBVTTS_C),
                new SideloadedCaptionsData("spanish",  "es", WEBVTTS_D));*/
    }

    @Override
    public void onResume() {
        Log.d(TAG, "OnResume");
        if (mVideoPlayerView != null) {
            mVideoPlayerView.resume();
        }
        super.onResume();
    }

    @Override
    public void onPause() {
        Log.d(TAG, "OnPause");
        if(mVideoPlayerView != null){
            mVideoPlayerView.pause();
        }
        super.onPause();
    }

    @Override
    public void onDestroy() {
        Log.d(TAG, "OnDestroy");
        if (mVideoPlayerView!=null) {
            mVideoPlayerView.stop();
            mVideoPlayerView.onDestroy();
        }
        super.onDestroy();
    }

    @Override
    public void onAttach(Activity activity) {
        super.onAttach(activity);
    }

    @Override
    public boolean onPlayerEvent(int eventID) {
        if(eventID == IPlayerEventsListener.PLAYER_EVENT_TYPE_STARTED)
        {
            List<SideloadedCaptionsData> subtitles = captionComponent.getSideloadedCaptions();
            if (subtitles.isEmpty())
                return true;

            captionComponent.setTrackIndex(0);
            captionComponent.setVisibility(View.VISIBLE);
        }

        return true;
    }

    @Override
    public boolean onPlayerExtendedEvent(int eventID, int arg1, int arg2) {
        if(eventID == IPlayerEventsListener.PLAYER_EXTENDED_EVENT_SEEKING_SUCCEDEED)
            Log.d(TAG, "Event Type: PLAYER_EXTENDED_EVENT_SEEKING_SUCCEDED (" + eventID + ")");

        return true;
    }

    @Override
    public boolean onTouch(View v, MotionEvent event)
    {
        return false;
    }

}